.. include:: ../README.rst

Contents of Betamax's Documentation
===================================

.. toctree::
   :caption: Narrative Documentation
   :maxdepth: 3

   introduction
   long_term_usage
   configuring
   record_modes
   third_party_packages
   usage_patterns
   integrations

.. toctree::
   :caption: API Documentation
   :maxdepth: 2

   api
   cassettes
   implementation_details
   matchers
   serializers

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
